"""Top-level package for AuDoLab."""

__author__ = """Arne Tillmann and Gillian Kant"""
__email__ = "arne.tillmann.vellmar@gmail.com"
__version__ = '1.0.2'
